<?php
/*
 * All Back-End Helper Functions for Lawrules Theme
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/
 */

/* Validate px entered in field */
if( ! function_exists( 'lawrules_check_px' ) ) {
  function lawrules_check_px( $num ) {
    return ( is_numeric( $num ) ) ? $num . 'px' : $num;
  }
}

/* Escape Strings */
if( ! function_exists( 'lawrules_vt_esc_string' ) ) {
  function lawrules_vt_esc_string( $num ) {
    return preg_replace('/\D/', '', $num);
  }
}

/* Escape Numbers */
if( ! function_exists( 'lawrules_vt_esc_number' ) ) {
  function lawrules_vt_esc_number( $num ) {
    return preg_replace('/[^a-zA-Z]/', '', $num);
  }
}

/* Inline Style */
global $all_inline_styles;
$all_inline_styles = array();
if( ! function_exists( 'lawrules_add_inline_style' ) ) {
  function lawrules_add_inline_style( $style ) {
    global $all_inline_styles;
    array_push( $all_inline_styles, $style );
  }
}

/* HEX to RGB */
if( ! function_exists( 'lawrules_vt_hex2rgb' ) ) {
  function lawrules_vt_hex2rgb( $hexcolor, $opacity = 1 ) {

    if( preg_match( '/^#[a-fA-F0-9]{6}|#[a-fA-F0-9]{3}$/i', $hexcolor ) ) {

      $hex    = str_replace( '#', '', $hexcolor );

      if( strlen( $hex ) == 3 ) {
        $r    = hexdec( substr( $hex, 0, 1 ) . substr( $hex, 0, 1 ) );
        $g    = hexdec( substr( $hex, 1, 1 ) . substr( $hex, 1, 1 ) );
        $b    = hexdec( substr( $hex, 2, 1 ) . substr( $hex, 2, 1 ) );
      } else {
        $r    = hexdec( substr( $hex, 0, 2 ) );
        $g    = hexdec( substr( $hex, 2, 2 ) );
        $b    = hexdec( substr( $hex, 4, 2 ) );
      }

      return ( isset( $opacity ) && $opacity != 1 ) ? 'rgba('. $r .', '. $g .', '. $b .', '. $opacity .')' : ' ' . $hexcolor;

    } else {

      return $hexcolor;

    }

  }
}

/* Yoast Plugin Metabox Low */
if( ! function_exists( 'lawrules_vt_yoast_metabox' ) ) {
  function lawrules_vt_yoast_metabox() {
    return 'low';
  }
  add_filter( 'wpseo_metabox_prio', 'lawrules_vt_yoast_metabox' );
}

if( ! function_exists( 'lawrules_is_post_type' ) ) {
  function lawrules_is_post_type($type){
    global $wp_query;
    if($type == get_post_type($wp_query->post->ID)) return true;
    return false;
  }
}

/**
 * If WooCommerce Plugin Activated
 */
if ( ! function_exists( 'lawrules_is_woocommerce_activated' ) ) {
  function lawrules_is_woocommerce_activated() {
    if ( class_exists( 'woocommerce' ) ) { return true; } else { return false; }
  }
}

/**
 * If is WooCommerce Shop
 */
if ( ! function_exists( 'lawrules_is_woocommerce_shop' ) ) {
  function lawrules_is_woocommerce_shop() {
    if ( lawrules_is_woocommerce_activated() && is_shop() ) { return true; } else { return false; }
  }
}

/**
 * If is WPML is active
 */
if ( ! function_exists( 'lawrules_is_wpml_activated' ) ) {
  function lawrules_is_wpml_activated() {
    if ( class_exists( 'SitePress' ) ) { return true; } else { return false; }
  }
}

/**
 * Remove Rev Slider Metabox
 */
if ( is_admin() ) {
  if( ! function_exists( 'lawrules_remove_rev_slider_meta_boxes' ) ) {
    function lawrules_remove_rev_slider_meta_boxes() {
      remove_meta_box( 'mymetabox_revslider_0', 'page', 'normal' );
      remove_meta_box( 'mymetabox_revslider_0', 'post', 'normal' );
      remove_meta_box( 'mymetabox_revslider_0', 'team', 'normal' );
      remove_meta_box( 'mymetabox_revslider_0', 'testimonial', 'normal' );
    }
    add_action( 'do_meta_boxes', 'lawrules_remove_rev_slider_meta_boxes' );
  }
}

/* Custom Styles */
if( ! function_exists( 'lawrules_vt_custom_css' ) ) {
  function lawrules_vt_custom_css() {
    wp_enqueue_style('lawrules-default-style', get_template_directory_uri() . '/style.css');
    if( function_exists( 'lawrules_compress_css_lines' ) ) {
      $output = lawrules_dynamic_styles();
      $custom_css = lawrules_compress_css_lines( $output );
    }

    wp_add_inline_style( 'lawrules-default-style', $custom_css );
  }
}

/**
 * Check if Codestar Framework is Active or Not!
 */
if ( ! function_exists( 'lawrules_framework_active' ) ) {
  function lawrules_framework_active() {
    return ( class_exists( 'CSF' ) ) ? true : false;
  }
}

// A Custom function for Lawrules Options
if ( ! function_exists( 'cs_get_option' ) ) {
  function cs_get_option( $option = '', $default = null ) {
    $options = get_option( 'lawrules_csf_theme_options' ); // Attention: Set your unique id of the framework
    return ( isset( $options[$option] ) ) ? $options[$option] : $default;
  }
}

// A Custom function for Lawrules Customizer Options
if ( ! function_exists( 'cs_get_customize_option' ) ) {
  function cs_get_customize_option( $option = '', $default = null ) {
    $options = get_option( 'lawrules_csf_customizer' ); // Attention: Set your unique id of the framework
    return ( isset( $options[$option] ) ) ? $options[$option] : $default;
  }
}
