<?php
/*
 * All Front-End Helper Functions
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/
 */

/* Exclude category from blog */
if( ! function_exists( 'lawrules_vt_excludeCat' ) ) {
  function lawrules_vt_excludeCat($query) {
  	if ( $query->is_home ) {
  		$exclude_cat_ids = cs_get_option('theme_exclude_categories');
  		if($exclude_cat_ids) {
  			foreach( $exclude_cat_ids as $exclude_cat_id ) {
  				$exclude_from_blog[] = '-'. $exclude_cat_id;
  			}
  			$query->set('cat', implode(',', $exclude_from_blog));
  		}
  	}
  	return $query;
  }
  add_filter('pre_get_posts', 'lawrules_vt_excludeCat');
}

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function lawrules_pingback_header() {
  if ( is_singular() && pings_open() ) {
    echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
  }
}
add_action( 'wp_head', 'lawrules_pingback_header' );

/* Include Default value for dropdown in contact form7*/
function lawrules_wpcf7_form_elements($html) {
    $text = esc_html__('Choose', 'lawrules');
    $html = str_replace('---',  $text , $html);
    return $html;
}
add_filter('wpcf7_form_elements', 'lawrules_wpcf7_form_elements');

/* Tag Cloud Widget - Remove Inline Font Size */
add_filter( 'widget_tag_cloud_args', 'lawrules_change_tag_cloud_font_sizes');

/**
 * Change the Tag Cloud's Font Sizes.
 *
 * @since 1.0.0
 *
 * @param array $args
 *
 * @return array
 */
function lawrules_change_tag_cloud_font_sizes( array $args ) {
  $args['smallest'] = '10';
  $args['largest'] = '10';

  return $args;
}

/* Excerpt Length */
class LawrulesExcerpt {

  // Default length (by WordPress)
  public static $length = 55;

  // Output: lawrules_excerpt('short');
  public static $types = array(
    'short' => 25,
    'regular' => 55,
    'long' => 100
  );

  /**
   * Sets the length for the excerpt,
   * then it adds the WP filter
   * And automatically calls the_excerpt();
   *
   * @param string $new_length
   * @return void
   * @author Baylor Rae'
   */
  public static function length($new_length = 55) {
    LawrulesExcerpt::$length = $new_length;
    add_filter('excerpt_length', 'LawrulesExcerpt::new_length');
    LawrulesExcerpt::output();
  }

  // Tells WP the new length
  public static function new_length() {
    if( isset(LawrulesExcerpt::$types[LawrulesExcerpt::$length]) )
      return LawrulesExcerpt::$types[LawrulesExcerpt::$length];
    else
      return LawrulesExcerpt::$length;
  }

  // Echoes out the excerpt
  public static function output() {
    the_excerpt();
  }

}

// Custom Excerpt Length
if( ! function_exists( 'lawrules_excerpt' ) ) {
  function lawrules_excerpt($length = 55) {
    LawrulesExcerpt::length($length);
  }
}

if ( ! function_exists( 'lawrules_new_excerpt_more' ) ) {
  function lawrules_new_excerpt_more( $more ) {
    return esc_html__('[...]' ,'lawrules');
  }
  add_filter('excerpt_more', 'lawrules_new_excerpt_more');
}

/* Tag Cloud Widget - Remove Inline Font Size */
if( ! function_exists( 'lawrules_vt_tag_cloud' ) ) {
  function lawrules_vt_tag_cloud($tag_string){
    return preg_replace("/style='font-size:.+pt;'/", '', $tag_string);
  }
  add_filter('wp_generate_tag_cloud', 'lawrules_vt_tag_cloud', 10, 3);
}

/* Password Form */
if( ! function_exists( 'lawrules_vt_password_form' ) ) {
  function lawrules_vt_password_form( $output ) {
    $output = str_replace( 'type="submit"', 'type="submit" class=""', $output );
    return $output;
  }
  add_filter('the_password_form' , 'lawrules_vt_password_form');
}

/* Maintenance Mode */
if( ! function_exists( 'lawrules_vt_maintenance_mode' ) ) {
  function lawrules_vt_maintenance_mode(){

    $maintenance_mode_page = cs_get_option( 'maintenance_mode_page' );
    $enable_maintenance_mode = cs_get_option( 'enable_maintenance_mode' );

    if ( isset($enable_maintenance_mode) && ! empty( $maintenance_mode_page ) && ! is_user_logged_in() ) {
      get_template_part('layouts/post/content', 'maintenance');
      exit;
    }

  }
  add_action( 'wp', 'lawrules_vt_maintenance_mode', 1 );
}

/* Widget Layouts */
if ( ! function_exists( 'lawrules_vt_footer_widgets' ) ) {
  function lawrules_vt_footer_widgets() {

    $output = '';
    $footer_widget_layout = cs_get_option('footer_widget_layout');

    if( $footer_widget_layout ) {

      switch ( $footer_widget_layout ) {
        case 1: $widget = array('piece' => 1, 'class' => 'col-md-12'); break;
        case 2: $widget = array('piece' => 2, 'class' => 'col-md-6'); break;
        case 3: $widget = array('piece' => 3, 'class' => 'col-md-4'); break;
        case 4: $widget = array('piece' => 4, 'class' => 'col-lg-3 col-md-6'); break;
        case 5: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 1); break;
        case 6: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 2); break;
        case 7: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 3); break;
        case 8: $widget = array('piece' => 4, 'class' => 'col-lg-2 col-md-4', 'layout' => 'col-lg-6 col-md-12', 'queue' => 1); break;
        case 9: $widget = array('piece' => 4, 'class' => 'col-md-2', 'layout' => 'col-md-6', 'queue' => 4); break;
        case 10: $widget = array('piece' => 5, 'class' => 'col-xl-2 col-md-4', 'layout' => 'col-xl-3 col-md-4', 'queue' => 2, 'layout_two' => 'col-xl-3 col-md-4', 'queue_two' => 5); break;
        default : $widget = array('piece' => 4, 'class' => 'col-md-3'); break;
      }

      for( $i = 1; $i < $widget["piece"]+1; $i++ ) {
        if(isset( $widget["queue_two"] ) && $widget["queue_two"] == $i ){
          $widget_cls = ( isset( $widget["queue_two"] ) && $widget["queue_two"] == $i ) ? $widget["layout_two"] : '';
          $widget_class = '';
        } else {
          $widget_class = ( isset( $widget["queue"] ) && $widget["queue"] == $i ) ? $widget["layout"] : $widget["class"];
          $widget_cls = '';
        }
        $output .= '<div class="'. $widget_class .' lawyr-item '.$widget_cls.'">';
        ob_start();
        if (is_active_sidebar('footer-'. $i)) {
          dynamic_sidebar( 'footer-'. $i );
        }
        $output .= ob_get_clean();
        $output .= '</div>';
      }
    }
    return $output;
  }
}

if( ! function_exists( 'lawrules_vt_top_bar' ) ) {
  function lawrules_vt_top_bar() {

    $out     = '';
    if ( ( cs_get_option( 'top_left' ) || cs_get_option( 'top_right' ) ) ) {
      $out .= '<div class="lawyr-topbar"><div class="container"><div class="row">';
      $out .= lawrules_vt_top_bar_modules( 'left' );
      $out .= lawrules_vt_top_bar_modules( 'right' );
      $out .= '</div></div></div>';
    }
    return $out;
  }
}

/* WP Link Pages */
if ( ! function_exists( 'lawrules_wp_link_pages' ) ) {
  function lawrules_wp_link_pages() {
    $defaults = array(
      'before'           => '<div class="wp-link-pages">' . esc_html__( 'Pages:', 'lawrules' ),
      'after'            => '</div>',
      'link_before'      => '<span>',
      'link_after'       => '</span>',
      'next_or_number'   => 'number',
      'separator'        => ' ',
      'pagelink'         => '%',
      'echo'             => 1
    );
    wp_link_pages( $defaults );
  }
}
/* Navigation Widget add class */
function lawrules_add_menuclass($ulclass) {
   return preg_replace('/<a /', '<a class="nav-link" ', $ulclass);
}
add_filter('wp_nav_menu','lawrules_add_menuclass');

/* Navigation Widget add class on li */
function lawrules_add_classes_on_li($classes, $item, $args) {
  $classes[] = 'nav-item';
  return $classes;
}
add_filter('nav_menu_css_class','lawrules_add_classes_on_li',1,3);

/* ==============================================
   Custom Comment Area Modification
=============================================== */
if ( ! function_exists( 'lawrules_comment_modification' ) ) {
  function lawrules_comment_modification($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment;
    extract($args, EXTR_SKIP);
    if ( 'div' == $args['style'] ) {
      $tag = 'div';
      $add_below = 'comment';
    } else {
      $tag = 'li';
      $add_below = 'div-comment';
    }
    $comment_class = empty( $args['has_children'] ) ? '' : 'parent';
  ?>

  <<?php echo esc_attr($tag); ?> <?php comment_class('item ' . $comment_class .' ' ); ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
    <div id="div-comment-<?php comment_ID() ?>" class="comment-item">
    <?php endif; ?>
    <div class="comment-theme">
        <div class="comment-image">
          <?php if ( $args['avatar_size'] != 0 ) {
            echo get_avatar( $comment, 72 );
          } ?>
        </div>
    </div>
    <div class="comment-main-area">
      <div class="comment-wrapper">
        <div class="lawyr-comments-meta">
          <h5><?php printf( '%s', get_comment_author() ); ?></h5>
          <div class="comments-reply">
          <?php
            comment_reply_link( array_merge( $args, array(
            'reply_text' => '<span class="comment-reply-link">'. esc_html__('Reply','lawrules') .'</span>',
            'before' => '',
            'class'  => '',
            'depth' => $depth,
            'max_depth' => $args['max_depth']
            ) ) );
          ?>
          </div>
        </div>
        <?php if ( $comment->comment_approved == '0' ) : ?>
        <em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'lawrules' ); ?></em>
        <?php endif; ?>
        <div class="comment-area">
          <?php comment_text(); ?>
        </div>
      </div>
    </div>
  <?php if ( 'div' != $args['style'] ) : ?>
  </div>
  <?php endif;
  }
}

/* Title Area */
if ( ! function_exists( 'lawrules_title_area' ) ) {
  function lawrules_title_area() {

    global $post, $wp_query;
    // Get post meta in all type of WP pages
    $lawrules_id    = ( isset( $post ) ) ? $post->ID : 0;
    $lawrules_id    = ( is_home() ) ? get_option( 'page_for_posts' ) : $lawrules_id;
    $lawrules_id    = ( lawrules_is_woocommerce_shop() ) ? wc_get_page_id( 'shop' ) : $lawrules_id;
    $lawrules_meta  = get_post_meta( $lawrules_id, 'page_type_metabox', true );
    if ($lawrules_meta && (!is_archive() || lawrules_is_woocommerce_shop())) {
      $custom_title = $lawrules_meta['page_custom_title'];
      if ($custom_title) {
        $custom_title = $custom_title;
      } else {
        $custom_title = '';
      }
    } else { $custom_title = ''; }

    /**
     * For strings with necessary HTML, use the following:
     * Note that I'm only including the actual allowed HTML for this specific string.
     * More info: https://codex.wordpress.org/Function_Reference/wp_kses
     */
    $allowed_title_area_tags = array(
        'a' => array(
          'href' => array(),
        ),
        'span' => array(
          'class' => array(),
        )
    );

    if( $custom_title && !is_search()) {
      echo esc_html($custom_title);
    } elseif ( is_home() ) {
      bloginfo('description');
    } elseif( is_singular('tribe_events') ) {
      echo esc_html(get_the_title($wp_query->post->ID));
    } elseif( is_singular('product') ) {
      $post_type = get_post_type_object( get_post_type($post) );
      echo esc_html($post_type->label);
    } elseif ( is_search() ) {
      printf( esc_html__( 'Search Results for %s', 'lawrules' ), '<span>' . get_search_query() . '</span>' );
    } elseif ( is_category() || is_tax() ){
      single_cat_title();
    } elseif ( is_tag() ){
      single_tag_title(esc_html__('Posts Tagged: ', 'lawrules'));
    } elseif ( is_archive() ){
      if ( is_day() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'lawrules' ), $allowed_title_area_tags ), get_the_date());
      } elseif ( is_month() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'lawrules' ), $allowed_title_area_tags ), get_the_date( 'F, Y' ));
      } elseif ( is_year() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'lawrules' ), $allowed_title_area_tags ), get_the_date( 'Y' ));
      } elseif ( is_author() ) {
        printf( wp_kses( __( 'Posts by: <span>%s</span>', 'lawrules' ), $allowed_title_area_tags ), get_the_author_meta( 'display_name', $wp_query->post->post_author ));
      } elseif( lawrules_is_woocommerce_shop() ) {
        esc_html_e( 'Shop', 'lawrules' );
      } elseif ( is_post_type_archive() ) {
        post_type_archive_title();
      } else {
        esc_html_e( 'Archives', 'lawrules' );
      }
    } else {
      the_title();
    }

  }
}

/**
 * Pagination Function
 */
if ( ! function_exists( 'lawrules_default_paging_nav' ) ) {
  function lawrules_default_paging_nav($nav_query = NULL) {
    if ( function_exists('wp_pagenavi')) {
      echo '<div class="pagination-wrap"><div class="lawyr-pagination"><div class="lawyr-pagenavi">';
      wp_pagenavi();
      echo '</div></div></div>';
    } else {
      global $wp_query;
      ob_start();
      $big = 999999999;
      $current = max( 1, get_query_var('paged') );
      $total = ($nav_query != NULL) ? $nav_query->max_num_pages : $wp_query->max_num_pages;

      if($wp_query->max_num_pages == '1' ) {} else {echo '';}
      echo '<div class="pagination-wrap"><div class="lawyr-pagination"><div class="lawyr-pagenavi">';
      $pagination = paginate_links( array(
        'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
        'format' => '?paged=%#%',
        'prev_text' => '<i class="fa fa-angle-left"></i>',
        'next_text' => ' <i class="fa fa-angle-right"></i>',
        'current' => $current,
        'total' => $total,
        'type' => 'array'
      ));
      if ( ! empty( $pagination ) ) : ?>
      <ul class="pagination wpse64458_pagination">
      <?php foreach ( $pagination as $key => $page_link ) : ?>
        <li class="page-item<?php if ( strpos( $page_link, 'current' ) !== false ) { echo ' active'; } ?>"><?php echo str_replace( 'page-numbers', 'page-link', $page_link ); ?></li>
      <?php endforeach ?>
      </ul>
      <?php endif;
      echo '</div></div></div>';
      if($wp_query->max_num_pages == '1' ) {} else {echo '';}
      echo ob_get_clean();
    }
  }
}

if ( ! function_exists( 'lawrules_paging_nav' ) ) {
  function lawrules_paging_nav($numpages = '', $pagerange = '', $paged='') {

      if (empty($pagerange)) {
        $pagerange = 2;
      }
      if (empty($paged)) {
        $paged = 1;
      } else {
        $paged = $paged;
      }
      if ($numpages == '') {
        global $wp_query;
        $numpages = $wp_query->max_num_pages;
        if(!$numpages) {
          $numpages = 1;
        }
      }
      global $wp_query;
      $big = 999999999;
      if($wp_query->max_num_pages != '1' ) { ?>
      <div class="lawyr-pagination">
        <?php echo paginate_links( array(
          'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
          'format' => '?paged=%#%',
          'prev_text' => '<i class="fa fa-angle-left"></i>',
          'next_text' => '<i class="fa fa-angle-right"></i>',
          'current' => $paged,
          'total' => $numpages,
          'type' => 'list'
        )); ?>
      </div>
    <?php }
  }
}

/**
 * Custom Pagination Function
 */
if ( ! function_exists( 'lawrules_custom_paging_nav' ) ) {
  function lawrules_custom_paging_nav($numpages = '', $pagerange = '', $paged='') {
    if (empty($pagerange)) {
      $pagerange = 2;
    }
    if (empty($paged)) {
      $paged = 1;
    } else {
      $paged = $paged;
    }
    if ($numpages == '') {
      global $wp_query;
      $numpages = $wp_query->max_num_pages;
      if(!$numpages) {
        $numpages = 1;
      }
    }
    $big = 999999999; ?>
    <div class="lawyr-pagenavi">
      <?php echo paginate_links( array(
        'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
        'format' => '?page=%#%',
        'prev_text' => '<i class="fa fa-angle-left" aria-hidden="true"></i>',
        'next_text' => '<i class="fa fa-angle-right" aria-hidden="true"></i>',
        'current' => $paged,
        'total' => $numpages,
        'type' => 'list'
      )); ?>
  </div>
<?php
  }
}
/* Added next class to wp-pagenavi*/
add_filter('wp_pagenavi_class_nextpostslink', 'lawrules_pagination_nextpostslink_class');
function lawrules_pagination_nextpostslink_class($class_name) {
  return 'next';
}
// Custom Post Type limit
function lawrules_custom_posts_per_page( $query ) {
  if ( post_type_exists( 'team' ) ) {
    if ( is_post_type_archive('team') ) {
      $team_limit = cs_get_option('team_limit');
      $team_limit = $team_limit ? $team_limit : '6';
      if ( $query->query_vars['post_type'] === 'team' ) $query->query_vars['posts_per_page'] = $team_limit;
    }
  }
  if ( post_type_exists( 'practicearea' ) ) {
    if ( is_post_type_archive('practicearea') ) {
      $practice_area_limit = cs_get_option('practice_area_limit');
      $practice_area_limit = $practice_area_limit ? $practice_area_limit : '6';
      if ( $query->query_vars['post_type'] === 'practicearea' ) $query->query_vars['posts_per_page'] = $practice_area_limit;
    }
    if (is_tax('practicearea_category')) {
      $practice_area_limit = cs_get_option('practice_area_limit');
      $practice_area_limit = $practice_area_limit ? $practice_area_limit : '6';
      $query->set('posts_per_page', $practice_area_limit);
    }
  }
  return $query;
}
add_filter( 'pre_get_posts', 'lawrules_custom_posts_per_page' );

if( ! function_exists( 'lawrules_reading_time_default' ) ) {
  function lawrules_reading_time_default() {
    global $reading_time_post_types, $reading_time_shortcodes;
    $update_options = array(
    'label'              => 'Reading Time: ',
    'postfix'            => 'minutes',
    'postfix_singular'   => 'minute',
    'wpm'                => '300',
    'before_content'     => false,
    'before_excerpt'     => false,
    'exclude_images'     => false,
    'post_types'         => $reading_time_post_types,
    'include_shortcodes' => $reading_time_shortcodes,
  );

  update_option( 'rt_reading_time_options', $update_options );
  }
  add_action( 'after_switch_theme', 'lawrules_reading_time_default' );
}

if( ! function_exists( 'lawrules_reading_time_default_after' ) ) {
  function lawrules_reading_time_default_after() {
    global $reading_time_post_types, $reading_time_shortcodes;
    $update_options = array(
    'label'              => 'Reading Time: ',
    'postfix'            => 'minutes',
    'postfix_singular'   => 'minute',
    'wpm'                => '300',
    'before_content'     => false,
    'before_excerpt'     => false,
    'exclude_images'     => false,
    'post_types'         => $reading_time_post_types,
    'include_shortcodes' => $reading_time_shortcodes,
  );

  update_option( 'rt_reading_time_options', $update_options );
  }
  add_action( 'pt-ocdi/after_content_import_execution', 'lawrules_reading_time_default_after' );
}

if( ! function_exists( 'lawrules_is_elementor' ) ) {
  function lawrules_is_elementor(){
    $lawrules_page = get_post( cs_get_option('maintenance_mode_page') );
    if (Elementor\Plugin::instance()->db->is_built_with_elementor( $lawrules_page->ID )) {
      return true;
    } else {
      return null;
    }
  }
}

/**
 * Filter the categories archive widget to add a span around post count
 */
function lawrules_cat_count_span( $links ) {
  $links = str_replace( '</a> (', '</a><span class="post-count">(', $links );
  $links = str_replace( ')', ')</span>', $links );
  return $links;
}
add_filter( 'wp_list_categories', 'lawrules_cat_count_span' );

/**
 * Filter the archives widget to add a span around post count
 */
function lawrules_archive_count_span( $links ) {
  $links = str_replace( '</a>&nbsp;(', '</a><span class="post-count">(', $links );
  $links = str_replace( ')', ')</span>', $links );
  return $links;
}
add_filter( 'get_archives_link', 'lawrules_archive_count_span' );
