<?php
/*
 * All WooCommerce Related Functions
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/
 */

if ( class_exists( 'WooCommerce' ) ) {

	/**
	* Insert the opening anchor tag for products in the loop.
	*/
	function lawrules_product_wrap_open() {
		echo '<div class="product-wrap">';
	}
	add_action( 'lawrules_open_wrap', 'lawrules_product_wrap_open', 1 );

	/**
	 * Insert the opening anchor tag for products in the loop.
	 */
	function lawrules_product_wrap_close() {
		echo '</div>';
	}
	add_action( 'lawrules_close_wrap', 'lawrules_product_wrap_close', 1 );

	// Product Column Limit - Shop Page
	add_filter('loop_shop_columns', 'lawrules_loop_columns');
	if ( ! function_exists('lawrules_loop_columns') ) {
		function lawrules_loop_columns() {
			$col = cs_get_option('woo_product_columns');
			if($col) {
				return $col;
			} else {
				return 3;
			}
		}
	}

  // Remove Product Image And wrap with div and add to cart
  remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );
  remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );
	remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
	remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
	if ( ! function_exists( 'lawrules_template_loop_product_link_open' ) ) {

		/**
		 * Show the product title in the product loop. By default this is an H2.
		 */
		function lawrules_template_loop_product_link_open( $args = array() ) {
			global $product;

			$link = apply_filters( 'woocommerce_loop_product_link', get_the_permalink(), $product );

			echo '<div class="lawyr-image"><a href="' . esc_url( $link ) . '" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">';
			wc_get_template( 'loop/sale-flash.php' );
			echo woocommerce_get_product_thumbnail(); // WPCS: XSS ok.
			echo '</a>';
				global $product;

			if ( $product ) {
				$defaults = array(
					'quantity'   => 1,
					'class'      => implode( ' ', array_filter( array(
						'button',
						'product_type_' . $product->get_type(),
						$product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
						$product->supports( 'ajax_add_to_cart' ) ? 'ajax_add_to_cart' : '',
					) ) ),
					'attributes' => array(
						'data-product_id'  => $product->get_id(),
						'data-product_sku' => $product->get_sku(),
						'aria-label'       => $product->add_to_cart_description(),
						'rel'              => 'nofollow',
					),
				);

				$args = apply_filters( 'woocommerce_loop_add_to_cart_args', wp_parse_args( $args, $defaults ), $product );

				wc_get_template( 'loop/add-to-cart.php', $args );
				echo '</div>';
			}
		}
	}
	add_action( 'woocommerce_shop_loop_item_title', 'lawrules_template_loop_product_link_open', 10 );

	// Remove a link close tag in product listing
	remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );

	// Remove the product rating display on product loops
  remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );

  /* Remove Product Title action and added with h4 tag */
  remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10 );

  if ( ! function_exists( 'lawrules_template_loop_product_title' ) ) {

		/**
		 * Show the product title in the product loop. By default this is an H2.
		 */
		function lawrules_template_loop_product_title() {
			global $product;
			$link = apply_filters( 'woocommerce_loop_product_link', get_the_permalink(), $product );
			echo '<h4 class="woocommerce-loop-product__title"><a href="' . esc_url( $link ) . '" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">' . esc_html(get_the_title()) . '</a></h4>';
		}
	}
	add_action( 'woocommerce_shop_loop_item_title', 'lawrules_template_loop_product_title', 10 );

	// Remove Product description title
	add_filter( 'woocommerce_product_description_heading', 'remove_product_description_heading' );
	function remove_product_description_heading() {
		return '';
	}

	add_filter('woocommerce_product_additional_information_heading', 'isa_product_additional_information_heading');
	function isa_product_additional_information_heading() {
    return '';
	}

	// WooCommerce Products per Page Limit
	add_filter( 'loop_shop_per_page', 'lawrules_product_limit', 20 );
	if ( ! function_exists('lawrules_product_limit') ) {
	  function lawrules_product_limit() {
	    $woo_limit = cs_get_option('theme_woo_limit');
	    $woo_limit = $woo_limit ? $woo_limit : '9';
	    return $woo_limit;
	  }
	}

	// Remove Shop Page Title
	add_filter( 'woocommerce_show_page_title' , 'lawrules_hide_page_title' );
	function lawrules_hide_page_title() {
		return false;
	}

	// Single Product Single/Gallery Script
	add_action( 'after_setup_theme', 'lawrules_single_product_gallery_image' );
	function lawrules_single_product_gallery_image() {
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );
	}

	// Single Product Page - Related Products Limit & columns
	add_filter( 'woocommerce_output_related_products_args', 'lawrules_related_products_args' );
  function lawrules_related_products_args( $args ) {
  	$woo_related_limit = cs_get_option('woo_related_limit');
  	$columns = cs_get_option('woo_product_columns');
  	if ($woo_related_limit) {
			$args['posts_per_page'] = (int)$woo_related_limit; // 4 related products
		} else {
			$args['posts_per_page'] = 4; // 4 related products
		}
		if($columns) {
			$args['columns'] = (int)$columns;
		} else {
			$args['columns'] = 3;
		}
		return $args;
	}

	// Related Products Title Change
  $related_title = cs_get_option('woo_related_title');
  function custom_related_products_text( $translated_text, $text, $domain ) {
  $related_title = cs_get_option('woo_related_title');
    switch ( $translated_text ) {
      case 'Related products' :
        $translated_text = $related_title;
        break;
    }
    return $translated_text;
  }
  if($related_title){
    add_filter( 'gettext', 'custom_related_products_text', 20, 3 );
  }

	// Define image sizes
	function lawrules_woo_image_dimensions() {
		global $pagenow;

		if ( ! isset( $_GET['activated'] ) || $pagenow != 'themes.php' ) {
			return;
		}
  	$catalog = array(
			'width' 	=> '442',
			'height'	=> '330',
			'crop'		=> 1
		);
		$single = array(
			'width' 	=> '992',
			'height'	=> '768',
			'crop'		=> 1
		);
		$thumbnail = array(
			'width' 	=> '144',
			'height'	=> '144',
			'crop'		=> 1
		);
		// Image sizes
		update_option( 'shop_catalog_image_size', $catalog ); // Product category thumbs
		update_option( 'shop_single_image_size', $single ); // Single product image
		update_option( 'shop_thumbnail_image_size', $thumbnail ); // Image gallery thumbs
	}
	add_action( 'after_switch_theme', 'lawrules_woo_image_dimensions', 1 );
  
	// Remove You May Also Like section
	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
  $woo_single_upsell = cs_get_option('woo_single_upsell');
  if($woo_single_upsell) {
		add_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_upsells', 20);
		if (!function_exists('woocommerce_output_upsells')) {
			function woocommerce_output_upsells() {
				$columns = cs_get_option('up_sell_column');
				$columns = $columns ? $columns : '3';
			    woocommerce_upsell_display(3,$columns); // Display 3 products in rows of 3
			}
		}
	}

	// Remove Cross sell section
	$woo_single_crosssell = cs_get_option('woo_single_crosssell');
	if(!$woo_single_crosssell) {
		remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );
	}

  // Remove Related Products section
  $woo_single_related = cs_get_option('woo_single_related');
  if(!$woo_single_related) {
		remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
  }

	// Product thumbnail column set to 1
	add_filter( 'woocommerce_product_thumbnails_columns', 'lawrules_single_gallery_columns', 99 );
	function lawrules_single_gallery_columns() {
	 return 1; 
	}

} // class_exists => WooCommerce
