<?php
/*
 * All Theme Options for Lawrules theme.
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/
 */

// Control core classes for avoid errors
if( class_exists( 'CSF' ) ) {

  // Set a unique slug-like ID
  $prefix = 'lawrules_csf_theme_options';

  // Create options
  CSF::createOptions( $prefix, array(
    'menu_title'      => LAWRULES_NAME . esc_html__(' Options', 'lawrules'),
    'menu_slug'       => sanitize_title(LAWRULES_NAME) . '_options',
    'menu_type'       => 'menu',
    'menu_icon'       => 'dashicons-awards',
    'menu_position'   => '4',
    'ajax_save'       => false,
    'show_reset_all'  => true,
    'framework_title' => LAWRULES_NAME .' <small>V-'. LAWRULES_VERSION .' by <a href="'. LAWRULES_BRAND_URL .'" target="_blank">'. LAWRULES_BRAND_NAME .'</a></small>',
  ) );

  // Brand
  CSF::createSection( $prefix, array(
    'name'     => 'theme_brand',
    'title'    => esc_html__('Logo', 'lawrules'),
    'icon'     => 'fa fa-bookmark',
    'fields' => array(

      // Site Logo
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('Site Logo', 'lawrules'),
      ),
      array(
        'id'    => 'brand_logo_default',
        'type'  => 'media',
        'url'   => false,
        'title' => esc_html__('Logo', 'lawrules'),
        'desc' => esc_html__('Upload your 2x size of logo here. It\'ll comfortable for retina screens.', 'lawrules'),
        'button_title' => esc_html__('Add Logo', 'lawrules'),
      ),
      array(
        'id'    => 'logo_width_height',
        'type'  => 'dimensions',
        'title'       => esc_html__('Logo Width & Height', 'lawrules'),
        'unit'  => false,
      ),
      array(
        'id'    => 'brand_logo_top_bottom',
        'type'  => 'spacing',
        'title' => esc_html__('Logo Top & Bottom Space', 'lawrules'),
        'left'  => false,
        'right' => false,
      ),

      // WordPress Admin Logo
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('WordPress Admin Logo', 'lawrules'),
      ),
      array(
        'id'    => 'brand_logo_wp',
        'type'  => 'media',
        'url'   => false,
        'title' => esc_html__('Login logo', 'lawrules'),
        'desc' => esc_html__('Upload your WordPress login page logo here.', 'lawrules'),
        'button_title' => esc_html__('Add Login logo', 'lawrules'),
      ),

    )
  ) );

  // General
  CSF::createSection( $prefix, array(
    'name'     => 'theme_general',
    'title'    => esc_html__('General', 'lawrules'),
    'icon'     => 'fa fa-wrench',
    'fields' => array(
      
      array(
        'id'       => 'sticky_header',
        'type'     => 'switcher',
        'title'    => esc_html__('Sticky Header', 'lawrules'),
        'desc'     => esc_html__('Turn On if you want your naviagtion bar on sticky.', 'lawrules'),
        'text_on'  => 'Yes',
        'text_off' => 'No',
        'default' => true,
      ),
      array(
        'id'       => 'sticky_footer',
        'type'     => 'switcher',
        'title'    => esc_html__('Sticky Footer', 'lawrules'),
        'desc'     => esc_html__('If you turn this ON the footer will be sticky.', 'lawrules'),
        'text_on'  => 'Yes',
        'text_off' => 'No',
        'default' => false,
      ),
      array(
        'id'       => 'theme_preloader',
        'type'     => 'switcher',
        'title'    => esc_html__('Preloader', 'lawrules'),
        'desc'     => esc_html__('Turn off if you don\'t want preloader.', 'lawrules'),
        'text_on'  => 'Yes',
        'text_off' => 'No',
      ),
      array(
        'id'       => 'theme_btotop',
        'type'     => 'switcher',
        'title'    => esc_html__('Back To Top', 'lawrules'),
        'desc'     => esc_html__('Turn off if you don\'t want back to top button.', 'lawrules'),
        'text_on'  => 'Yes',
        'text_off' => 'No',
        'default' => true,
      ),
      array(
        'id'          => 'mobile_breakpoint',
        'type'        => 'text',
        'title'       => esc_html__('Mobile Menu Breakpoint', 'lawrules'),
        'desc' => esc_html__('Just put numeric value only. Like : 1199. Don\'t use px or any other units.', 'lawrules'),
      ),
      array(
        'id'       => 'theme_img_resizer',
        'type'     => 'switcher',
        'title'    => esc_html__('Disable Image Resizer?', 'lawrules'),
        'desc'     => esc_html__('Turn on if you don\'t want image resizer.', 'lawrules'),
      ),

    )
  ) );

  // Header Parent
  CSF::createSection( $prefix, array(
    'id'     => 'theme_header_tab',
    'title'    => esc_html__('Header', 'lawrules'),
    'icon'     => 'fa fa-bars',
  ) );

  // Design
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_header_tab',
    'name'     => 'header_design_tab',
    'title'    => esc_html__('Design', 'lawrules'),
    'icon'     => 'fa fa-magic',
    'fields' => array(

      array(
        'id'           => 'select_header_design',
        'type'         => 'image_select',
        'title'        => esc_html__('Select Header Design', 'lawrules'),
        'options'      => array(
          'style_one'    => LAWRULES_CS_IMAGES .'/hs-1.png',
          'style_two'    => LAWRULES_CS_IMAGES .'/hs-2.png',
        ),
        'attributes' => array(
          'data-depend-id' => 'header_design',
        ),
        'radio'        => true,
        'default'   => 'style_one',
        'info' => esc_html__('Select your header design, following options will may differ based on your selection of header design.', 'lawrules'),
      ),

      array(
        'id'       => 'need_content',
        'type'     => 'switcher',
        'title' => esc_html__('Need Header Content', 'lawrules'),
        'default' => true,
      ),
      array(
        'id'              => 'header_content',
        'title'           => esc_html__('Header Primary Content', 'lawrules'),
        'desc'            => esc_html__('Add your header primary content here. Example : Header Address Info', 'lawrules'),
        'type'            => 'textarea',
        'shortcoder'      => 'lawrules_vt_shortcodes',
        'dependency'   => array('need_content', '==', 'true'),
      ),
      array(
        'id'              => 'header_content_two',
        'title'           => esc_html__('Header Secondary Content', 'lawrules'),
        'desc'            => esc_html__('Add your header secondary content here. Example : Social Icons', 'lawrules'),
        'type'            => 'textarea',
        'shortcoder'      => 'lawrules_vt_shortcodes',
        'dependency'   => array('need_content', '==', 'true'),
      ),

    )
  ) );

  // header top bar
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_header_tab',
    'name'     => 'header_topbar_tab',
    'title'    => esc_html__('Top Bar', 'lawrules'),
    'icon'     => 'fa fa-magic',
    'fields' => array(

      array(
        'id'          => 'top_bar',
        'type'        => 'switcher',
        'title'       => esc_html__('Hide Top Bar', 'lawrules'),
        'on_text'     => esc_html__('Yes', 'lawrules'),
        'off_text'    => esc_html__('No', 'lawrules'),
        'default'     => false,
      ),
      array(
        'id'          => 'top_bar_in_responsive',
        'type'        => 'switcher',
        'title'       => esc_html__('Hide Top Bar in Responsive', 'lawrules'),
        'on_text'     => esc_html__('Yes', 'lawrules'),
        'off_text'    => esc_html__('No', 'lawrules'),
        'default'     => false,
      ),
      array(
        'id'        => 'topbar_style',
        'type'      => 'select',
        'title'     => esc_html__('Topbar Style', 'lawrules'),
        'options'   => array(
          'default-style' => 'Style One (Default)',
          'style-two'     => 'Style Two',
        ),
        'dependency'  => array('top_bar', '==', false),
      ),
      array(
        'id'          => 'top_left',
        'title'       => esc_html__('Top Left Block', 'lawrules'),
        'desc'        => esc_html__('Top bar left block.', 'lawrules'),
        'type'        => 'textarea',
        'shortcoder'      => 'lawrules_vt_shortcodes',
        'dependency'  => array('top_bar', '==', false),
      ),
      array(
        'id'          => 'top_right',
        'title'       => esc_html__('Top Right Block', 'lawrules'),
        'desc'        => esc_html__('Top bar right block.', 'lawrules'),
        'type'        => 'textarea',
        'shortcoder'      => 'lawrules_vt_shortcodes',
        'dependency'  => array('top_bar', '==', false),
      ),

    )
  ) );

  // Title Bar
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_header_tab',
    'name'     => 'header_banner_tab',
    'title'    => esc_html__('Title Bar (or) Banner', 'lawrules'),
    'icon'     => 'fa fa-bullhorn',
    'fields' => array(

      array(
        'id'       => 'need_title_bar',
        'type'     => 'switcher',
        'title'   => esc_html__('Title Bar', 'lawrules'),
        'desc'   => esc_html__('If you want title bar in your sub-pages, please turn this ON.', 'lawrules'),
        'default'     => true,
      ),
      array(
        'id'             => 'title_bar_padding',
        'type'           => 'select',
        'title'          => esc_html__('Padding Spaces Top & Bottom', 'lawrules'),
        'options'        => array(
          'padding-default' => esc_html__('Default Spacing', 'lawrules'),
          'padding-xs' => esc_html__('Extra Small Padding', 'lawrules'),
          'padding-sm' => esc_html__('Small Padding', 'lawrules'),
          'padding-md' => esc_html__('Medium Padding', 'lawrules'),
          'padding-lg' => esc_html__('Large Padding', 'lawrules'),
          'padding-xl' => esc_html__('Extra Large Padding', 'lawrules'),
          'padding-no' => esc_html__('No Padding', 'lawrules'),
          'padding-custom' => esc_html__('Custom Padding', 'lawrules'),
        ),
        'dependency'   => array( 'need_title_bar', '==', 'true' ),
      ),
      array(
        'id'    => 'titlebar_top_bottom_padding',
        'type'  => 'spacing',
        'title' => esc_html__('Title Bar Top & Bottom Space', 'lawrules'),
        'left'  => false,
        'right' => false,
        'dependency'   => array( 'title_bar_padding|need_title_bar', '==|==', 'padding-custom|true' ),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('Background Options', 'lawrules'),
      ),
      array(
        'id'      => 'titlebar_bg',
        'type'    => 'background',
        'title'   => esc_html__('Background', 'lawrules'),
        'background_color'      => true,
        'background_image'      => true,
        'background-position'   => true,
        'background_repeat'     => true,
        'background_attachment' => true,
        'background_size'       => true,
        'background_origin'     => true,
        'background_clip'       => true,
        'background_blend_mode' => true,
        'dependency' => array( 'need_title_bar', '==', 'true' ),
      ),

    )
  ) );

  // Footer
  CSF::createSection( $prefix, array(
    'name'     => 'footer_section',
    'title'    => esc_html__('Footer', 'lawrules'),
    'icon'     => 'fa fa-ellipsis-h',
    'fields' => array(

      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('Footer Widget Layout', 'lawrules')
      ),
      array(
        'id'    => 'footer_widget_block',
        'type'  => 'switcher',
        'title' => esc_html__('Enable Widget Block', 'lawrules'),
        'desc' => esc_html__('If you turn this ON, then Goto : Appearance > Widgets. There you can see Footer Widget 1,2,3 or 4 Widget Area, add your widgets there.', 'lawrules'),
        'default' => true,
      ),
      array(
        'id'    => 'footer_widget_layout',
        'type'  => 'image_select',
        'title' => esc_html__('Widget Layouts', 'lawrules'),
        'desc' => esc_html__('Choose your footer widget layouts.', 'lawrules'),
        'options' => array(
          1   => LAWRULES_CS_IMAGES . '/footer/footer-1.png',
          2   => LAWRULES_CS_IMAGES . '/footer/footer-2.png',
          3   => LAWRULES_CS_IMAGES . '/footer/footer-3.png',
          4   => LAWRULES_CS_IMAGES . '/footer/footer-4.png',
          5   => LAWRULES_CS_IMAGES . '/footer/footer-5.png',
          6   => LAWRULES_CS_IMAGES . '/footer/footer-6.png',
          7   => LAWRULES_CS_IMAGES . '/footer/footer-7.png',
          8   => LAWRULES_CS_IMAGES . '/footer/footer-8.png',
          9   => LAWRULES_CS_IMAGES . '/footer/footer-9.png',
          10  => LAWRULES_CS_IMAGES . '/footer/footer-10.png',
        ),
        'default' => 4,
        'dependency'  => array('footer_widget_block', '==', 'true'),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('Footer Top Widgets', 'lawrules')
      ),
      array(
        'id'        => 'above_footer_widget',
        'type'      => 'select',
        'title'     => esc_html__('Footer Top Widget', 'lawrules'),
        'options'   => array(
          'hide'   => 'Hide',
          'show' => 'Show',
        ),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('Copyright Layout', 'lawrules')
      ),
      array(
        'id'    => 'need_copyright',
        'type'  => 'switcher',
        'title' => esc_html__('Enable Copyright Section', 'lawrules'),
        'default' => true,
      ),
      array(
        'id'    => 'copyright_layout',
        'type'  => 'image_select',
        'title' => esc_html__('Select Copyright Layout', 'lawrules'),
        'options'      => array(
          'copyright-1'    => LAWRULES_CS_IMAGES .'/footer/copyright-1.png',
          'copyright-2'    => LAWRULES_CS_IMAGES .'/footer/copyright-2.png',
          'copyright-3'    => LAWRULES_CS_IMAGES .'/footer/copyright-3.png',
          ),
        'default'      => 'copyright-1',
        'dependency'     => array('need_copyright', '==', 'true'),
      ),
      array(
        'id'              => 'copyright_text',
        'title'           => esc_html__('Copyright Text', 'lawrules'),
        'desc'            => esc_html__('Helpful shortcodes: [lawrules_current_year] [lawrules_home_url] or any shortcode.', 'lawrules'),
        'type'            => 'textarea',
        'shortcoder'      => 'lawrules_vt_shortcodes',
        'dependency'      => array('need_copyright', '==', 'true'),
      ),
      array(
        'id'              => 'copyright_text_right',
        'title'           => esc_html__('Copyright Right Text', 'lawrules'),
        'desc'            => esc_html__('Add any shortcode.', 'lawrules'),
        'type'            => 'textarea',
        'shortcoder'      => 'lawrules_vt_shortcodes',
        'dependency'   => array('need_copyright|copyright_layout', '==|!=', 'true|copyright-3'),
      ),

    )
  ) );

  // Design Parent
  CSF::createSection( $prefix, array(
    'id'     => 'theme_design',
    'title'    => esc_html__('Design', 'lawrules'),
    'icon'     => 'fa fa-magic',
  ) );

  // Colors
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_design',
    'name'     => 'theme_color_section',
    'title'    => esc_html__('Colors', 'lawrules'),
    'icon'     => 'fa fa-eyedropper',
    'fields' => array(

      array(
        'type'    => 'heading',
        'content' => esc_html__('Color Options', 'lawrules'),
      ),
      array(
        'type'    => 'content',
        'content' => esc_html__('All color options are available in our theme customizer. The reason of we used customizer options for color section is because, you can choose each part of color from there and see the changes instantly using customizer. Highly customizable colors are in Appearance > Customize', 'lawrules'),
      ),

    )
  ) );

  // Typography
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_design',
    'name'     => 'theme_typo_section',
    'title'    => esc_html__('Typography', 'lawrules'),
    'icon'     => 'fa fa-header',
    'fields' => array(

      array(
        'id'            => 'theme_typo',
        'type'          => 'accordion',
        'title'         => esc_html__('Typography', 'lawrules'),
        'accordions'    => array(

          array(
            'title'     => esc_html__('Body Typography', 'lawrules'),
            'fields'    => array(
              array(
                'id'                 => 'body_font',
                'type'               => 'typography',
                'title'              => esc_html__('Typography', 'lawrules'),
                'font_family'        => true,
                'font_weight'        => true,
                'font_style'         => true,
                'font_size'          => true,
                'line_height'        => true,
                'letter_spacing'     => true,
                'text_align'         => true,
                'text-transform'     => true,
                'color'              => true,
                'subset'             => true,
                'backup_font_family' => true,
                'font_variant'       => true,
                'word_spacing'       => true,
                'text_decoration'    => true,
                'default'            => array(
                  'font-family'      => 'Fira Sans',
                  'type'             => 'google',
                ),
              ),
              array(
                'id'              => 'body_css',
                'type'            => 'textarea',
                'title'           => esc_html__('Custom CSS', 'lawrules'),
                'desc'            => esc_html__('Enter your Custom CSS separated with ( , ) Ex: .class1, .class2', 'lawrules'),
              ),
            )
          ),
          array(
            'title'     => esc_html__('Menu Typography', 'lawrules'),
            'fields'    => array(
              array(
                'id'                 => 'menu_font',
                'type'               => 'typography',
                'title'              => esc_html__('Typography', 'lawrules'),
                'font_family'        => true,
                'font_weight'        => true,
                'font_style'         => true,
                'font_size'          => true,
                'line_height'        => true,
                'letter_spacing'     => true,
                'text_align'         => true,
                'text-transform'     => true,
                'color'              => true,
                'subset'             => true,
                'backup_font_family' => true,
                'font_variant'       => true,
                'word_spacing'       => true,
                'text_decoration'    => true,
                'default'            => array(
                  'font-family'      => 'Open Sans',
                  'type'             => 'google',
                ),
              ),
              array(
                'id'              => 'menu_css',
                'type'            => 'textarea',
                'title'           => esc_html__('Custom CSS', 'lawrules'),
                'desc'            => esc_html__('Enter your Custom CSS separated with ( , ) Ex: .class1, .class2', 'lawrules'),
              ),
            )
          ),
          array(
            'title'  => esc_html__('Sub Menu Typography', 'lawrules'),
            'fields'    => array(
              array(
                'id'                 => 'sub_menu_font',
                'type'               => 'typography',
                'title'              => esc_html__('Typography', 'lawrules'),
                'font_family'        => true,
                'font_weight'        => true,
                'font_style'         => true,
                'font_size'          => true,
                'line_height'        => true,
                'letter_spacing'     => true,
                'text_align'         => true,
                'text-transform'     => true,
                'color'              => true,
                'subset'             => true,
                'backup_font_family' => true,
                'font_variant'       => true,
                'word_spacing'       => true,
                'text_decoration'    => true,
                'default'            => array(
                  'font-family'      => 'Open Sans',
                  'type'             => 'google',
                ),
              ),
              array(
                'id'              => 'sub_menu_css',
                'type'            => 'textarea',
                'title'           => esc_html__('Custom CSS', 'lawrules'),
                'desc'            => esc_html__('Enter your Custom CSS separated with ( , ) Ex: .class1, .class2', 'lawrules'),
              ),
            )
          ),
          array(
            'title'  => esc_html__('Headings Typography', 'lawrules'),
            'fields'    => array(
              array(
                'id'                 => 'headings_font',
                'type'               => 'typography',
                'title'              => esc_html__('Typography', 'lawrules'),
                'font_family'        => true,
                'font_weight'        => true,
                'font_style'         => true,
                'font_size'          => true,
                'line_height'        => true,
                'letter_spacing'     => true,
                'text_align'         => true,
                'text-transform'     => true,
                'color'              => true,
                'subset'             => true,
                'backup_font_family' => true,
                'font_variant'       => true,
                'word_spacing'       => true,
                'text_decoration'    => true,
                'default'            => array(
                  'font-family'      => 'Fira Sans',
                  'type'             => 'google',
                ),
              ),
              array(
                'id'              => 'headings_css',
                'type'            => 'textarea',
                'title'           => esc_html__('Custom CSS', 'lawrules'),
                'desc'            => esc_html__('Enter your Custom CSS separated with ( , ) Ex: .class1, .class2', 'lawrules'),
              ),
            )
          ),
          array(
            'title'  => esc_html__('Shortcode Elements Primary Font', 'lawrules'),
            'fields'    => array(
              array(
                'id'                 => 'shortcode_prime_font',
                'type'               => 'typography',
                'title'              => esc_html__('Typography', 'lawrules'),
                'font_family'        => true,
                'font_weight'        => true,
                'font_style'         => true,
                'font_size'          => true,
                'line_height'        => true,
                'letter_spacing'     => true,
                'text_align'         => true,
                'text-transform'     => true,
                'color'              => true,
                'subset'             => true,
                'backup_font_family' => true,
                'font_variant'       => true,
                'word_spacing'       => true,
                'text_decoration'    => true,
                'default'            => array(
                  'font-family'      => 'Open Sans',
                  'type'             => 'google',
                ),
              ),
              array(
                'id'              => 'shortcode_prime_css',
                'type'            => 'textarea',
                'title'           => esc_html__('Custom CSS', 'lawrules'),
                'desc'            => esc_html__('Enter your Custom CSS separated with ( , ) Ex: .class1, .class2', 'lawrules'),
              ),
            )
          ),
          array(
            'title'  => esc_html__('Shortcode Elements Secondary Font', 'lawrules'),
            'fields'    => array(
              array(
                'id'                 => 'shortcode_secon_font',
                'type'               => 'typography',
                'title'              => esc_html__('Typography', 'lawrules'),
                'font_family'        => true,
                'font_weight'        => true,
                'font_style'         => true,
                'font_size'          => true,
                'line_height'        => true,
                'letter_spacing'     => true,
                'text_align'         => true,
                'text-transform'     => true,
                'color'              => true,
                'subset'             => true,
                'backup_font_family' => true,
                'font_variant'       => true,
                'word_spacing'       => true,
                'text_decoration'    => true,
                'default'            => array(
                  'font-family'      => 'Open Sans',
                  'type'             => 'google',
                ),
              ),
              array(
                'id'              => 'shortcode_secon_css',
                'type'            => 'textarea',
                'title'           => esc_html__('Custom CSS', 'lawrules'),
                'desc'            => esc_html__('Enter your Custom CSS separated with ( , ) Ex: .class1, .class2', 'lawrules'),
              ),
            )
          ),

        )
      ),

      array(
        'id'        => 'custom_typography',
        'type'      => 'group',
        'title'     => esc_html__('Custom Typography', 'lawrules'),
        'fields'    => array(
          array(
            'id'    => 'custom_title',
            'type'  => 'text',
            'title' => esc_html__('Title', 'lawrules'),
          ),
          array(
            'id'                 => 'custom_typo',
            'type'               => 'typography',
            'title'              => esc_html__('Typography', 'lawrules'),
            'font_family'        => true,
            'font_weight'        => true,
            'font_style'         => true,
            'font_size'          => true,
            'line_height'        => true,
            'letter_spacing'     => true,
            'text_align'         => true,
            'text-transform'     => true,
            'color'              => true,
            'subset'             => true,
            'backup_font_family' => true,
            'font_variant'       => true,
            'word_spacing'       => true,
            'text_decoration'    => true,
            'default'            => array(
              'font-family'      => 'Noto Sans',
              'type'             => 'google',
            ),
          ),
          array(
            'id'              => 'custom_css',
            'type'            => 'textarea',
            'title'           => esc_html__('Custom CSS', 'lawrules'),
            'desc'            => esc_html__('Enter your Custom CSS separated with ( , ) Ex: .class1, .class2', 'lawrules'),
          ),
        ),
      ),

      // Custom Fonts Upload
      array(
        'id'                 => 'custom_font_family',
        'type'               => 'group',
        'title'              => esc_html__('Upload Custom Fonts', 'lawrules'),
        'button_title'       => esc_html__('Add New Custom Font', 'lawrules'),
        'accordion_title'    => esc_html__('Adding New Font', 'lawrules'),
        'accordion'          => true,
        'desc'               => 'It is simple. Only add your custom fonts and click to save. After you can check "Font Family" selector. Do not forget to Save!',
        'fields'             => array(

          array(
            'id'             => 'name',
            'type'           => 'text',
            'title'          => esc_html__('Font-Family Name', 'lawrules'),
            'attributes'     => array(
              'placeholder'  => 'for eg. Arial'
            ),
          ),

          array(
            'id'            => 'weight',
            'type'          => 'select',
            'title'         => esc_html__('Font Weight', 'lawrules'),
            'options'       => array(
              '100'         => esc_html__('Thin 100', 'lawrules'),
              '100italic'   => esc_html__('Thin 100 Italic', 'lawrules'),
              '200'         => esc_html__('Extra Light 200', 'lawrules'),
              '200italic'   => esc_html__('Extra Light 200 Italic', 'lawrules'),
              '300'         => esc_html__('Light 300', 'lawrules'),
              '300italic'   => esc_html__('Light 300 Italic', 'lawrules'),
              '400'         => esc_html__('Regular 400', 'lawrules'),
              '400italic'   => esc_html__('Regular 400 Italic', 'lawrules'),
              '500'         => esc_html__('Medium 500', 'lawrules'),
              '500italic'   => esc_html__('Medium 500 Italic', 'lawrules'),
              '600'         => esc_html__('Semi Bold 600', 'lawrules'),
              '600italic'   => esc_html__('Semi Bold 600 Italic', 'lawrules'),
              '700'         => esc_html__('Bold 700', 'lawrules'),
              '700italic'   => esc_html__('Bold 700 Italic', 'lawrules'),
              '800'         => esc_html__('Extra Bold 800', 'lawrules'),
              '800italic'   => esc_html__('Extra Bold 800 Italic', 'lawrules'),
              '900'         => esc_html__('Black 900', 'lawrules'),
              '900italic'   => esc_html__('Black 900 Italic', 'lawrules'),
            ),
            'placeholder'   => esc_html__('Select font weight', 'lawrules'),
          ),

          array(
            'id'             => 'ttf',
            'type'           => 'upload',
            'title'          => 'Upload .ttf <small><i>(optional)</i></small>',
            'library'        => 'font',
            'button_title'   => 'Upload <i>.ttf</i>',
          ),

          array(
            'id'             => 'eot',
            'type'           => 'upload',
            'title'          => 'Upload .eot <small><i>(optional)</i></small>',
            'library'        => 'font',
            'button_title'   => 'Upload <i>.eot</i>',
          ),

          array(
            'id'             => 'otf',
            'type'           => 'upload',
            'title'          => 'Upload .otf <small><i>(optional)</i></small>',
            'library'        => 'font',
            'button_title'   => 'Upload <i>.otf</i>',
          ),

          array(
            'id'             => 'woff',
            'type'           => 'upload',
            'title'          => 'Upload .woff <small><i>(optional)</i></small>',
            'library'        => 'font',
            'button_title'   => 'Upload <i>.woff</i>',
          ),

          array(
            'id'             => 'css',
            'type'           => 'textarea',
            'title'          => 'Extra CSS Style <small><i>(optional)</i></small>',
            'attributes'     => array(
              'placeholder'  => 'for eg. font-weight: normal;'
            ),
          ),

        ),
      ),
      // End All field

    )
  ) );

  // Post Parent
  CSF::createSection( $prefix, array(
    'id'       => 'theme_post_types',
    'title'    => esc_html__('Custom Post Types', 'lawrules'),
    'icon'     => 'fa fa-files-o',
  ) );
 
  // Practice Area
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_post_types',
    'name'     => 'practice_area_section',
    'title'    => esc_html__('Practice Area', 'lawrules'),
    'icon'     => 'fa fa-briefcase',
    'fields'   => array(

      // Practice Area Name
      array(
        'id'            => 'noneed_practice_area_post',
        'type'          => 'switcher',
        'title'         => esc_html__('Disable Practice Area Post?', 'lawrules'),
        'desc'          => esc_html__('If need to disable this post type, please turn this ON.', 'lawrules'),
        'default'       => false,
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__('Name Change', 'lawrules'),
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_practice_area_name',
        'type'          => 'text',
        'title'         => esc_html__('Practice Area Name', 'lawrules'),
        'attributes'    => array(
          'placeholder' => 'Practice Area'
        ),
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_practice_area_slug',
        'type'          => 'text',
        'title'         => esc_html__('Practice Area Slug', 'lawrules'),
        'attributes'    => array(
          'placeholder' => 'practicearea-item'
        ),
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_practice_area_cat_slug',
        'type'          => 'text',
        'title'         => esc_html__('Practice Area Category Slug', 'lawrules'),
        'attributes'    => array(
          'placeholder' => 'practicearea-category'
        ),
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'danger',
        'content'       => esc_html__('Important: Please do not set case studies slug and page slug as same. It\'ll not work.', 'lawrules'),
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
      ),
      // Practice Area Name
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__('Practice Area Listing & Style', 'lawrules'),
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'id'             => 'practice_area_style',
        'type'           => 'select',
        'title'          => esc_html__('Practice Area Style', 'lawrules'),
        'options'        => array(
          'one'          => esc_html__('Style One', 'lawrules'),
          'two'          => esc_html__('Style Two', 'lawrules'),
          'three'          => esc_html__('Style Three', 'lawrules'),
          'four'          => esc_html__('Style Four', 'lawrules'),
        ),
        'placeholder' => esc_html__('Select Style', 'lawrules'),
        'dependency'   => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'id'             => 'practice_area_col',
        'type'           => 'select',
        'title'          => esc_html__('Practice Area Column', 'lawrules'),
        'options'        => array(
          'three'          => esc_html__('Three', 'lawrules'),
          'four'          => esc_html__('Four', 'lawrules'),
        ),
        'placeholder' => esc_html__('Select Column', 'lawrules'),
        'dependency'   => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'id'            => 'practice_area_limit',
        'type'          => 'spinner',
        'title'         => esc_html__('Practice Area Limit', 'lawrules'),
        'subtitle'      => esc_html__('max:100 | min:-1 | step:1', 'lawrules'),
        'max'           => 100,
        'min'           => -1,
        'step'          => 1,
        'default'       => 9,
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'id'            => 'practicearea_excerpt',
        'type'          => 'spinner',
        'title'         => esc_html__('Excerpt Length', 'lawrules'),
        'subtitle'      => esc_html__('max:200 | min:0 | step:1', 'lawrules'),
        'max'           => 200,
        'min'           => 0,
        'step'          => 1,
        'default'       => 35,
        'dependency'    => array('noneed_practice_area_post|practice_area_style', '==|==', 'false|three'),
      ),
      array(
        'id'            => 'practice_area_show_category',
        'type'          => 'select',
        'title'         => esc_html__('Practice Area Categories', 'lawrules'),
        'desc'          => esc_html__('Select categories you want to display.', 'lawrules'),
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
        'chosen'        => true,
        'multiple'      => true,
        'attributes'    => array(
          'style'       => 'width: 200px;'
        ),
        'options'       => 'categories',
        'query_args'  => array(
          'type'      => 'practicearea',
          'taxonomy'  => 'practicearea_category',
        ),
        'placeholder'   => esc_html__('Select categories', 'lawrules'),
      ),
      array(
        'id'            => 'practice_area_orderby',
        'type'          => 'select',
        'title'         => esc_html__('Order By', 'lawrules'),
        'options'       => array(
          'none'        => esc_html__('None', 'lawrules'),
          'ID'          => esc_html__('ID', 'lawrules'),
          'author'      => esc_html__('Author', 'lawrules'),
          'title'       => esc_html__('Title', 'lawrules'),
          'date'        => esc_html__('Date', 'lawrules'),
          'name'        => esc_html__('Name', 'lawrules'),
          'modified'    => esc_html__('Modified', 'lawrules'),
          'rand'        => esc_html__('Random', 'lawrules'),
          'menu_order'  => esc_html__('Menu Order', 'lawrules'),
        ),
        'placeholder'   => esc_html__('Select Practice Area Order By', 'lawrules'),
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'id'            => 'practice_area_order',
        'type'          => 'select',
        'title'         => esc_html__('Order', 'lawrules'),
        'options'       => array(
          'ASC'         => esc_html__('Asending', 'lawrules'),
          'DESC'        => esc_html__('Desending', 'lawrules'),
        ),
        'placeholder'   => esc_html__('Select Practice Area Order', 'lawrules'),
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__('Enable/Disable Options', 'lawrules'),
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'id'            => 'practice_area_aqr',
        'type'          => 'switcher',
        'title'         => esc_html__('Disable Image Resize?', 'lawrules'),
        'desc'          => esc_html__('If need to disable image resize, please turn this ON.', 'lawrules'),
        'default'       => false,
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__('Practice Area Single\'s Options', 'lawrules'),
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'id'             => 'area_sidebar_position',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Position', 'lawrules'),
        'options'        => array(
          'sidebar-right' => esc_html__('Right', 'lawrules'),
          'sidebar-left' => esc_html__('Left', 'lawrules'),
          'sidebar-hide' => esc_html__('Hide', 'lawrules'),
        ),
        'placeholder' => 'Select sidebar position',
        'help'          => esc_html__('This style will apply in practicearea singles', 'lawrules'),
        'desc'          => esc_html__('Default option : Right', 'lawrules'),
        'dependency'    => array('noneed_practice_area_post', '==', 'false'),
      ),
      array(
        'id'             => 'area_widget',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Widget', 'lawrules'),
        'options'        => 'sidebars',
        'placeholder'    => esc_html__('Select Widget', 'lawrules'),
        'dependency'     => array('area_sidebar_position|noneed_practice_area_post', '!=|==', 'sidebar-hide|false'),
        'desc'           => esc_html__('Default option : Main Widget Area', 'lawrules'),
      ),
      array(
        'id'             => 'area_sidebar_type',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Style', 'lawrules'),
        'options'        => array(
          'normal'       => esc_html__('Normal', 'lawrules'),
          'bar-sticky'   => esc_html__('Sticky', 'lawrules'),
          'bar-float'    => esc_html__('Floating', 'lawrules'),
        ),
        'placeholder' => 'Select sidebar Style',
        'dependency'     => array('area_sidebar_position|noneed_practice_area_post', '!=|==', 'sidebar-hide|false'),
      ),

    )
  ) );

  // Testimonial
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_post_types',
    'name'     => 'testimonial_section',
    'title'    => esc_html__('Testimonial', 'lawrules'),
    'icon'     => 'fa fa-commenting',
    'fields'   => array(

      // Testimonial Name
      array(
        'id'            => 'noneed_testimonial_post',
        'type'          => 'switcher',
        'title'         => esc_html__('Disable Testimonial Post?', 'lawrules'),
        'desc'          => esc_html__('If need to disable this post type, please turn this ON.', 'lawrules'),
        'default'       => false,
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__('Name Change', 'lawrules'),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_testimonial_name',
        'type'          => 'text',
        'title'         => esc_html__('Testimonial Name', 'lawrules'),
        'attributes'    => array(
          'placeholder' => 'Testimonial'
        ),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_testimonial_slug',
        'type'          => 'text',
        'title'         => esc_html__('Testimonial Slug', 'lawrules'),
        'attributes'    => array(
          'placeholder' => 'testimonial-item'
        ),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_testimonial_cat_slug',
        'type'          => 'text',
        'title'         => esc_html__('Testimonial Category Slug', 'lawrules'),
        'attributes'    => array(
          'placeholder' => 'testimonial-category'
        ),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'danger',
        'content'       => esc_html__('Important: Please do not set testimonial slug and page slug as same. It\'ll not work.', 'lawrules'),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      // Testimonial Name
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__('Testimonial Listing & Style', 'lawrules'),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'id'             => 'testimonial_style',
        'type'           => 'select',
        'title'          => esc_html__('Testimonial Style', 'lawrules'),
        'options'        => array(
          'style-one'       => esc_html__('Style One', 'lawrules'),
          'style-two'   => esc_html__('Style Two', 'lawrules'),
          'style-three'   => esc_html__('Style Three', 'lawrules'),
        ),
        'placeholder' => 'Select testimonial Style',
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'id'            => 'testimonial_limit',
        'type'          => 'spinner',
        'title'         => 'Testimonial Limit',
        'subtitle'      => 'max:100 | min:-1 | step:1',
        'max'           => 100,
        'min'           => -1,
        'step'          => 1,
        'default'       => 9,
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'id'            => 'testimonial_orderby',
        'type'          => 'select',
        'title'         => esc_html__('Order By', 'lawrules'),
        'options'       => array(
          'none'        => esc_html__('None', 'lawrules'),
          'ID'          => esc_html__('ID', 'lawrules'),
          'author'      => esc_html__('Author', 'lawrules'),
          'title'       => esc_html__('Title', 'lawrules'),
          'date'        => esc_html__('Date', 'lawrules'),
          'name'        => esc_html__('Name', 'lawrules'),
          'modified'    => esc_html__('Modified', 'lawrules'),
          'rand'        => esc_html__('Random', 'lawrules'),
          'menu_order'  => esc_html__('Menu Order', 'lawrules'),
        ),
        'placeholder'   => esc_html__('Select Testimonial Order By', 'lawrules'),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'id'            => 'testimonial_order',
        'type'          => 'select',
        'title'         => esc_html__('Order', 'lawrules'),
        'options'       => array(
          'ASC'         => esc_html__('Asending', 'lawrules'),
          'DESC'        => esc_html__('Desending', 'lawrules'),
        ),
        'placeholder'   => esc_html__('Select Testimonial Order', 'lawrules'),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),

    )
  ) );

  // Team
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_post_types',
    'name'     => 'team_section',
    'title'    => esc_html__('Team', 'lawrules'),
    'icon'     => 'fa fa-users',
    'fields'   => array(

      // Team Name
      array(
        'id'            => 'noneed_team_post',
        'type'          => 'switcher',
        'title'         => esc_html__('Disable Team Post?', 'lawrules'),
        'desc'          => esc_html__('If need to disable this post type, please turn this ON.', 'lawrules'),
        'default'       => false,
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__('Name Change', 'lawrules'),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_team_name',
        'type'          => 'text',
        'title'         => esc_html__('Team Name', 'lawrules'),
        'attributes'    => array(
          'placeholder' => 'Team'
        ),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_team_slug',
        'type'          => 'text',
        'title'         => esc_html__('Team Slug', 'lawrules'),
        'attributes'    => array(
          'placeholder' => 'team-item'
        ),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_team_cat_slug',
        'type'          => 'text',
        'title'         => esc_html__('Team Category Slug', 'lawrules'),
        'attributes'    => array(
          'placeholder' => 'team-category'
        ),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'danger',
        'content'       => esc_html__('Important: Please do not set team slug and page slug as same. It\'ll not work.', 'lawrules'),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      
      // Team Name
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__('Team Listing & Style', 'lawrules'),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'             => 'team_style',
        'type'           => 'select',
        'title'          => esc_html__('Team Style', 'lawrules'),
        'options'        => array(
          'one'       => esc_html__('Style One', 'lawrules'),
          'two'   => esc_html__('Style Two', 'lawrules'),
        ),
        'placeholder' => 'Select team Style',
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'team_limit',
        'type'          => 'spinner',
        'title'         => esc_html__('Team Limit', 'lawrules'),
        'subtitle'      => esc_html__('max:100 | min:-1 | step:1', 'lawrules'),
        'max'           => 100,
        'min'           => -1,
        'step'          => 1,
        'default'       => 9,
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'team_excerpt',
        'type'          => 'spinner',
        'title'         => esc_html__('Excerpt Length', 'lawrules'),
        'subtitle'      => esc_html__('max:200 | min:0 | step:1', 'lawrules'),
        'max'           => 200,
        'min'           => 0,
        'step'          => 1,
        'default'       => 35,
        'dependency'    => array('team_style', '==', 'two'),
      ),
      array(
        'id'            => 'team_orderby',
        'type'          => 'select',
        'title'         => esc_html__('Order By', 'lawrules'),
        'options'       => array(
          'none'        => esc_html__('None', 'lawrules'),
          'ID'          => esc_html__('ID', 'lawrules'),
          'author'      => esc_html__('Author', 'lawrules'),
          'title'       => esc_html__('Title', 'lawrules'),
          'date'        => esc_html__('Date', 'lawrules'),
          'name'        => esc_html__('Name', 'lawrules'),
          'modified'    => esc_html__('Modified', 'lawrules'),
          'rand'        => esc_html__('Random', 'lawrules'),
          'menu_order'  => esc_html__('Menu Order', 'lawrules'),
        ),
        'placeholder'   => esc_html__('Select Team Order By', 'lawrules'),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'team_order',
        'type'          => 'select',
        'title'         => esc_html__('Order', 'lawrules'),
        'options'       => array(
          'ASC'         => esc_html__('Asending', 'lawrules'),
          'DESC'        => esc_html__('Desending', 'lawrules'),
        ),
        'placeholder'   => esc_html__('Select Team Order', 'lawrules'),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'team_aqr',
        'type'          => 'switcher',
        'title'         => esc_html__('Disable Image Resize?', 'lawrules'),
        'desc'          => esc_html__('If you need to disable image resize, please turn this ON.', 'lawrules'),
        'default'       => false,
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'team_pagination',
        'type'          => 'switcher',
        'title'         => esc_html__('Pagination', 'lawrules'),
        'desc'          => esc_html__('If you need pagination in team pages, please turn this ON.', 'lawrules'),
        'default'       => true,
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),

      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__('Team Single', 'lawrules'),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'             => 'team_sidebar_position',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Position', 'lawrules'),
        'options'        => array(
          'sidebar-right' => esc_html__('Right', 'lawrules'),
          'sidebar-left' => esc_html__('Left', 'lawrules'),
          'sidebar-hide' => esc_html__('Hide', 'lawrules'),
        ),
        'placeholder' => 'Select sidebar position',
        'help'          => esc_html__('This style will apply in team single pages.', 'lawrules'),
        'desc'          => esc_html__('Default option : Right', 'lawrules'),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'             => 'team_widget',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Widget', 'lawrules'),
        'options'        => 'sidebars',
        'placeholder'    => esc_html__('Select Widget', 'lawrules'),
        'dependency'     => array('team_sidebar_position|noneed_team_post', '!=|==', 'sidebar-hide|false'),
        'desc'           => esc_html__('Default option : Main Widget Area', 'lawrules'),
      ),
      array(
        'id'             => 'team_sidebar_type',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Style', 'lawrules'),
        'options'        => array(
          'normal'       => esc_html__('Normal', 'lawrules'),
          'bar-sticky'   => esc_html__('Sticky', 'lawrules'),
          'bar-float'    => esc_html__('Floating', 'lawrules'),
        ),
        'placeholder' => 'Select sidebar Style',
        'dependency'     => array('team_sidebar_position|noneed_team_post', '!=|==', 'sidebar-hide|false'),
      ),

    )
  ) );

  // Blog
  CSF::createSection( $prefix, array(
    'id'       => 'blog_section',
    'title'    => esc_html__('Blog', 'lawrules'),
    'icon'     => 'fa fa-edit',
  ) );

  // General
  CSF::createSection( $prefix, array(
    'parent'   => 'blog_section',
    'name'     => 'blog_general_tab',
    'title'    => esc_html__('General', 'lawrules'),
    'icon'     => 'fa fa-cog',
    'fields' => array(

      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('Layout', 'lawrules')
      ),      
      array(
        'id'             => 'blog_sidebar_position',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Position', 'lawrules'),
        'options'        => array(
          'sidebar-right' => esc_html__('Right', 'lawrules'),
          'sidebar-left' => esc_html__('Left', 'lawrules'),
          'sidebar-hide' => esc_html__('Hide', 'lawrules'),
        ),
        'placeholder' => 'Select sidebar position',
        'help'          => esc_html__('This style will apply, default blog pages - Like : Archive, Category, Tags, Search & Author.', 'lawrules'),
        'desc'          => esc_html__('Default option : Right', 'lawrules'),
      ),
      array(
        'id'             => 'blog_widget',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Widget', 'lawrules'),
        'options'        => 'sidebars',
        'placeholder'    => esc_html__('Select Widget', 'lawrules'),
        'dependency'     => array('blog_sidebar_position', '!=', 'sidebar-hide'),
        'desc'           => esc_html__('Default option : Main Widget Area', 'lawrules'),
      ),
      array(
        'id'             => 'sidebar_type',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Style', 'lawrules'),
        'options'        => array(
          'normal'       => esc_html__('Normal', 'lawrules'),
          'bar-sticky'   => esc_html__('Sticky', 'lawrules'),
          'bar-float'    => esc_html__('Floating', 'lawrules'),
        ),
        'placeholder' => 'Select sidebar Style',
        'dependency'     => array('blog_sidebar_position', '!=', 'sidebar-hide'),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('Global Options', 'lawrules')
      ),
      array(
        'id'             => 'blog_style',
        'type'           => 'select',
        'title'          => esc_html__('Blog Listing Style', 'lawrules'),
        'options'        => array(
          'style-one'       => esc_html__('Style One', 'lawrules'),
          'style-two'   => esc_html__('Style Two', 'lawrules'),
        ),
        'placeholder' => 'Select Blog Style',
      ),
      array(
        'id'             => 'blog_listing_column',
        'type'           => 'select',
        'title'          => esc_html__('Blog Listing Column', 'lawrules'),
        'options'        => array(
          'two'       => esc_html__('Two Column', 'lawrules'),
          'three'   => esc_html__('Three Column', 'lawrules'),
          'four'    => esc_html__('Four Column', 'lawrules'),
        ),
        'placeholder' => 'Blog Listing Column',
        'dependency'     => array('blog_style', '==', 'style-two'),
      ),
      array(
        'id'         => 'theme_exclude_categories',
        'type'       => 'checkbox',
        'title'      => esc_html__('Exclude Categories', 'lawrules'),
        'desc'      => esc_html__('Select categories you want to exclude from blog page.', 'lawrules'),
        'options'    => 'categories',
      ),
      array(
        'id'      => 'theme_blog_home',
        'type'    => 'text',
        'title'   => esc_html__('Blog Home Page Link', 'lawrules'),
        'info'   => esc_html__('Enter blog home page link here.', 'lawrules'),
      ),
      array(
        'id'            => 'theme_blog_excerpt',
        'type'          => 'spinner',
        'title'         => esc_html__('Excerpt Length', 'lawrules'),
        'subtitle'      => esc_html__('max:200 | min:0 | step:1', 'lawrules'),
        'max'           => 200,
        'min'           => 0,
        'step'          => 1,
        'default'       => 35,
      ),
      array(
        'id'      => 'theme_metas_hide',
        'type'    => 'checkbox',
        'title'   => esc_html__('Meta\'s to hide in listing', 'lawrules'),
        'desc'    => esc_html__('Check items you want to hide from blog/post meta field.', 'lawrules'),
        'inline'  => true,
        'options'    => array(
          'category'   => esc_html__('Category', 'lawrules'),
          'date'    => esc_html__('Date', 'lawrules'),
          'author'     => esc_html__('Author', 'lawrules'),
          'comments'     => esc_html__('Comments', 'lawrules'),
        ),
      ),
      array(
        'id'        => "blog_date_format",
        'type'      => 'text',
        'title'     => esc_html__('Date Format', 'lawrules'),
        'desc'      => 'Enter date format (for more info <a href="https://codex.wordpress.org/Formatting_Date_and_Time" target="_blank">click here</a>)',
      ),

    )
  ) );

  // Single
  CSF::createSection( $prefix, array(
    'parent'   => 'blog_section',
    'name'     => 'blog_single_tab',
    'title'    => esc_html__('Single', 'lawrules'),
    'icon'     => 'fa fa-sticky-note',
    'fields' => array(

      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('Enable / Disable', 'lawrules')
      ),
      array(
        'id'      => 'theme_single_metas_hide',
        'type'    => 'checkbox',
        'title'   => esc_html__('Meta\'s to hide in single', 'lawrules'),
        'desc'    => esc_html__('Check items you want to hide from blog/post meta field.', 'lawrules'),
        'inline'  => true,
        'options'    => array(
          'date'    => esc_html__('Date', 'lawrules'),
          'category'   => esc_html__('Category', 'lawrules'),
          'tag'   => esc_html__('Tag', 'lawrules'),
          'share'    => esc_html__('Share', 'lawrules'),
          'author'     => esc_html__('Author', 'lawrules'),
          'comments'     => esc_html__('Comments', 'lawrules'),
        ),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('Related Posts', 'lawrules')
      ),
      array(
        'id'    => 'single_related_post',
        'type'  => 'switcher',
        'title' => esc_html__('Related Posts', 'lawrules'),
        'desc' => esc_html__('If need to hide related posts on single blog page, please turn this OFF.', 'lawrules'),
        'default' => true,
      ),
      array(
        'id'      => 'single_related_title',
        'type'    => 'text',
        'title'   => esc_html__('Section Title', 'lawrules'),
        'desc'   => esc_html__('Related post section title.', 'lawrules'),
        'dependency'     => array('single_related_post', '==', 'true'),
      ),
      array(
        'id'            => 'single_related_limit',
        'type'          => 'spinner',
        'title'         => esc_html__('Related Post Limit', 'lawrules'),
        'subtitle'      => esc_html__('max:100 | min:0 | step:1', 'lawrules'),
        'max'           => 100,
        'min'           => 0,
        'step'          => 1,
        'default'       => 2,
        'dependency'     => array('single_related_post', '==', 'true'),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('Sidebar', 'lawrules')
      ),
      array(
        'id'             => 'single_sidebar_position',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Position', 'lawrules'),
        'options'        => array(
          'sidebar-right' => esc_html__('Right', 'lawrules'),
          'sidebar-left' => esc_html__('Left', 'lawrules'),
          'sidebar-hide' => esc_html__('Hide', 'lawrules'),
        ),
        'placeholder' => 'Select sidebar position',
        'desc'          => esc_html__('Default option : Right', 'lawrules'),
      ),
      array(
        'id'             => 'single_blog_widget',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Widget', 'lawrules'),
        'options'        => 'sidebars',
        'placeholder'    => esc_html__('Select Widget', 'lawrules'),
        'dependency'     => array('single_sidebar_position', '!=', 'sidebar-hide'),
        'desc'           => esc_html__('Default option : Main Widget Area', 'lawrules'),
      ),
      array(
        'id'             => 'single_sidebar_type',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Style', 'lawrules'),
        'options'        => array(
          'normal'       => esc_html__('Normal', 'lawrules'),
          'bar-sticky'   => esc_html__('Sticky', 'lawrules'),
          'bar-float'    => esc_html__('Floating', 'lawrules'),
        ),
        'placeholder' => 'Select sidebar Style',
        'dependency'     => array('single_sidebar_position', '!=', 'sidebar-hide'),
      ),

    )
  ) );

  if (class_exists( 'WooCommerce' )) {
    // Woocommerce
    CSF::createSection( $prefix, array(
      'name'     => 'woocommerce_section',
      'title'    => esc_html__('Woocommerce', 'lawrules'),
      'icon'     => 'fa fa-shopping-cart',
      'fields' => array(

        array(
          'type'    => 'submessage',
          'style'   => 'info',
          'content' => esc_html__('Layout', 'lawrules')
        ),
        array(
          'id'             => 'woo_sidebar_position',
          'type'           => 'select',
          'title'          => esc_html__('Sidebar Position', 'lawrules'),
          'options'        => array(
            'right-sidebar' => esc_html__('Right', 'lawrules'),
            'left-sidebar' => esc_html__('Left', 'lawrules'),
            'sidebar-hide' => esc_html__('Hide', 'lawrules'),
          ),
          'placeholder' => esc_html__('Select sidebar position', 'lawrules'),
          'desc'          => esc_html__('Default option : Right', 'lawrules'),
        ),
        array(
          'id'             => 'woo_widget',
          'type'           => 'select',
          'title'          => esc_html__('Sidebar Widget', 'lawrules'),
          'options'        => 'sidebars',
          'placeholder' => esc_html__('Select Widget', 'lawrules'),
          'dependency'     => array('woo_sidebar_position', '!=', 'sidebar-hide'),
          'desc'           => esc_html__('Default option : Main Widget Area', 'lawrules'),
        ),
        array(
          'id'             => 'woo_sidebar_type',
          'type'           => 'select',
          'title'          => esc_html__('Sidebar Style', 'lawrules'),
          'options'        => array(
            'normal'       => esc_html__('Normal', 'lawrules'),
            'bar-sticky'   => esc_html__('Sticky', 'lawrules'),
            'bar-float'    => esc_html__('Floating', 'lawrules'),
          ),
          'placeholder' => 'Select sidebar Style',
          'dependency'     => array('woo_sidebar_position', '!=', 'sidebar-hide'),
        ),
        array(
          'type'    => 'submessage',
          'style'   => 'info',
          'content' => esc_html__('Single Product', 'lawrules')
        ),
        array(
          'id'    => 'woo_single_related',
          'type'  => 'switcher',
          'title' => esc_html__('Related Products', 'lawrules'),
          'desc' => esc_html__('If you want \'Related Products\' in single product page, please turn this ON.', 'lawrules'),
          'default' => false,
        ),
        array(
          'id'             => 'woo_related_limit',
          'type'           => 'text',
          'title'          => esc_html__('Related Products Limit', 'lawrules'),
          'dependency'     => array('woo_single_related', '==', 'true'),
        ),
        array(
          'id'             => 'woo_related_title',
          'type'           => 'text',
          'title'          => esc_html__('Related Products Title', 'lawrules'),
          'dependency'     => array('woo_single_related', '==', 'true'),
        ),
        array(
          'id'    => 'woo_single_upsell',
          'type'  => 'switcher',
          'title' => esc_html__('You May Also Like(Upsell)', 'lawrules'),
          'desc' => esc_html__('If you want \'You May Also Like\' products in single product page, please turn this ON.', 'lawrules'),
          'default' => false,
        ),
        array(
          'id'    => 'woo_single_crosssell',
          'type'  => 'switcher',
          'title' => esc_html__('You May interested in(Cross Sell)', 'lawrules'),
          'desc' => esc_html__('If you want \'You May interested in\' products in cart page, please turn this ON.', 'lawrules'),
          'default' => false,
        ),

      )
    ) );
  }

  // Extra Pages Parent
  CSF::createSection( $prefix, array(
    'id'       => 'theme_extra_pages',
    'title'    => esc_html__('Extra Pages', 'lawrules'),
    'icon'     => 'fa fa-clone',
  ) );

  // 404
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_extra_pages',
    'name'     => 'error_page_section',
    'title'    => esc_html__('404 Page', 'lawrules'),
    'icon'     => 'fa fa-exclamation-triangle',
    'fields' => array(

      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('404 Error Page Options', 'lawrules')
      ),
      array(
        'id'    => 'error_heading',
        'type'  => 'text',
        'title' => esc_html__('404 Page Heading', 'lawrules'),
        'desc'  => esc_html__('Enter 404 page heading.', 'lawrules'),
      ),
      array(
        'id'    => 'error_sub_heading',
        'type'  => 'text',
        'title' => esc_html__('404 Page Sub Heading', 'lawrules'),
        'desc'  => esc_html__('Enter 404 page sub heading.', 'lawrules'),
      ),
      array(
        'id'    => 'error_page_content',
        'type'  => 'textarea',
        'title' => esc_html__('404 Page Content', 'lawrules'),
        'desc'  => esc_html__('Enter 404 page content.', 'lawrules'),
      ),

    )
  ) );

  // Maintenance
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_extra_pages',
    'name'     => 'maintenance_mode_section',
    'title'    => esc_html__('Maintenance Mode', 'lawrules'),
    'icon'     => 'fa fa-hourglass-half',
    'fields'   => array(

      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('If you turn this ON : Only Logged in users will see your pages. All other visiters will see, selected page of : Maintenance Mode Page', 'lawrules')
      ),
      array(
        'id'    => 'enable_maintenance_mode',
        'type'  => 'switcher',
        'title' => esc_html__('Maintenance Mode', 'lawrules'),
        'default' => false,
      ),
      array(
        'id'    => 'elementor_page',
        'type'  => 'switcher',
        'title' => esc_html__('Elementor Page', 'lawrules'),
        'desc'  => esc_html__('Enable if your selected page is edited by elementor.', 'lawrules'),
        'default' => false,
        'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
      ),
      array(
        'id'             => 'maintenance_mode_page',
        'type'           => 'select',
        'title'          => esc_html__('Maintenance Mode Page', 'lawrules'),
        'options'        => 'pages',
        'placeholder'    => esc_html__('Select a page', 'lawrules'),
        'dependency'     => array( 'enable_maintenance_mode', '==', 'true' ),
      ),

    )
  ) );

  // Misc Parent
  CSF::createSection( $prefix, array(
    'id'       => 'misc_section',
    'title'    => esc_html__('Misc', 'lawrules'),
    'icon'     => 'fa fa-recycle',
  ) );

  // Custom Sidebar
  CSF::createSection( $prefix, array(
    'parent'   => 'misc_section',
    'name'     => 'custom_sidebar_section',
    'title'    => esc_html__('Custom Sidebar', 'lawrules'),
    'icon'     => 'fa fa-reorder',
    'fields'   => array(

      array(
        'id'     => 'custom_sidebar',
        'type'   => 'group',
        'title'           => esc_html__('Sidebars', 'lawrules'),
        'subtitle'        => esc_html__('Go to Appearance -> Widgets after create sidebars', 'lawrules'),
        'button_title'    => esc_html__('Add New Sidebar', 'lawrules'),
        'fields' => array(
          array(
            'id'    => 'sidebar_name',
            'type'  => 'text',
            'title' => esc_html__('Sidebar Name', 'lawrules'),
          ),
          array(
            'id'    => 'sidebar_desc',
            'type'  => 'text',
            'title' => esc_html__('Custom Description', 'lawrules'),
          ),
        ),
        'default'             => array(
            array(
              'sidebar_name'   => esc_html__('Above Footer', 'lawrules'),
              'sidebar_desc'   => esc_html__('Appears just above the footer in all Pages', 'lawrules'),
            ),
            array(
              'sidebar_name'   => esc_html__('Team Single', 'lawrules'),
              'sidebar_desc'   => esc_html__('Appears in All Team Single Pages', 'lawrules'),
            ),
          ),
      ),

    )
  ) );

  // Translation
  CSF::createSection( $prefix, array(
    'parent'   => 'misc_section',
    'name'     => 'theme_translation_section',
    'title'    => esc_html__('Translation', 'lawrules'),
    'icon'     => 'fa fa-language',
    'fields'   => array(

      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('Common Texts', 'lawrules')
      ),
      array(
        'id'          => 'read_more_text',
        'type'        => 'text',
        'title'       => esc_html__('Read More Text', 'lawrules'),
      ),
      array(
        'id'          => 'author_by_text',
        'type'        => 'text',
        'title'       => esc_html__('Author \'Posted by\' Text', 'lawrules'),
      ),
      array(
        'id'          => 'older_post',
        'type'        => 'text',
        'title'       => esc_html__('Previous Post Text', 'lawrules'),
      ),
      array(
        'id'          => 'newer_post',
        'type'        => 'text',
        'title'       => esc_html__('Next Post Text', 'lawrules'),
      ),
      array(
        'id'          => 'practice_area_read_more',
        'type'        => 'text',
        'title'       => esc_html__('Practice Area Read More', 'lawrules'),
      ),
      array(
        'id'          => 'share_text',
        'type'        => 'text',
        'title'       => esc_html__('Share Text', 'lawrules'),
      ),
      array(
        'id'          => 'post_comment_text',
        'type'        => 'text',
        'title'       => esc_html__('Post Comment Text [Submit Button]', 'lawrules'),
      ),

    )
  ) );

  // Backup
  CSF::createSection( $prefix, array(
    'name'     => 'backup_section',
    'title'    => 'Backup',
    'icon'     => 'fa fa-shield',
    'fields' => array(

      // Site Logo
      array(
        'type'    => 'submessage',
        'style'   => 'warning',
        'content' => esc_html__('You can save your current options. Download a Backup and Import.', 'lawrules'),
      ),
      array(
        'type'    => 'backup',
      ),

    )
  ) );

}